/*************************************************************
 *
 *  MathJax/jax/output/SVG/fonts/STIX-Web/Normal/BoldItalic/Main.js
 *  
 *  Copyright (c) 2013-2020 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.OutputJax['SVG'].FONTDATA.FONTS['STIXMathJax_Normal-bold-italic'] = {
  directory: 'Normal/BoldItalic',
  family: 'STIXMathJax_Normal',
  weight: 'bold',
  style: 'italic',
  id: 'STIXWEBNORMALBI',
  skew: {
    0x1D468: .16,
    0x1D469: .14,
    0x1D46A: .12,
    0x1D46B: .1,
    0x1D46C: .1,
    0x1D46D: .1,
    0x1D46E: .12,
    0x1D46F: .1,
    0x1D470: .1,
    0x1D471: .1,
    0x1D472: .1,
    0x1D473: .05,
    0x1D474: .08,
    0x1D475: .08,
    0x1D476: .12,
    0x1D477: .05,
    0x1D478: .12,
    0x1D479: .1,
    0x1D47A: .12,
    0x1D47D: -.05,
    0x1D47E: -.09,
    0x1D47F: .12,
    0x1D480: -.05,
    0x1D481: .1,
    0x1D482: .09,
    0x1D483: .03,
    0x1D484: .09,
    0x1D485: .22,
    0x1D486: .09,
    0x1D487: .19,
    0x1D488: .08,
    0x1D48A: .1,
    0x1D48B: .16,
    0x1D48D: .09,
    0x1D48E: .09,
    0x1D48F: .05,
    0x1D490: .09,
    0x1D491: .09,
    0x1D492: .1,
    0x1D493: .07,
    0x1D494: .07,
    0x1D495: .09,
    0x1D496: .05,
    0x1D497: .08,
    0x1D498: .1,
    0x1D499: .05,
    0x1D49A: .1,
    0x1D49B: .07,
    0x1D71C: .16,
    0x1D71D: .14,
    0x1D71E: .09,
    0x1D71F: .16,
    0x1D720: .14,
    0x1D721: .14,
    0x1D722: .1,
    0x1D723: .12,
    0x1D724: .1,
    0x1D725: .12,
    0x1D726: .16,
    0x1D727: .11,
    0x1D728: .1,
    0x1D729: .14,
    0x1D72A: .14,
    0x1D72B: .12,
    0x1D72C: .08,
    0x1D72D: .14,
    0x1D72E: .14,
    0x1D731: .12,
    0x1D732: .14,
    0x1D734: .16,
    0x1D735: .05,
    0x1D736: .05,
    0x1D737: .1,
    0x1D738: .05,
    0x1D739: .12,
    0x1D73A: .07,
    0x1D73B: .09,
    0x1D73C: .07,
    0x1D73D: .1,
    0x1D73E: .05,
    0x1D740: .07,
    0x1D741: .1,
    0x1D742: .07,
    0x1D743: .12,
    0x1D744: .08,
    0x1D745: .08,
    0x1D746: .1,
    0x1D747: .1,
    0x1D748: .05,
    0X1D749: .05,
    0x1D74A: .05,
    0x1D74B: .05,
    0x1D74C: .09,
    0x1D74E: .05,
    0x1D750: .1,
    0x1D751: .1,
    0X1D752: .05,
    0X1D753: .12,
    0x1D754: .1,
    0x1D755: .09,
  },
  0x20: [0,0,250,0,0,''],
  0xA0: [0,0,250,0,0,''],
  0x1D468: [685,0,759,39,724,'724 23l-2 -23h-319l4 23h31c33 0 51 17 51 45c0 10 -1 28 -2 34l-15 108h-159l-80 -139c-2 -4 -6 -13 -6 -22c0 -19 9 -26 22 -26h56l-6 -23h-260l4 23c45 5 74 17 108 75l346 587h49l94 -624c4 -24 20 -38 47 -38h37zM466 256l-23 178l-103 -178h126'],
  0x1D469: [669,0,726,42,715,'197 669h265c124 0 253 -22 253 -152c0 -74 -43 -120 -100 -147c-18 -9 -43 -18 -64 -24c58 -11 130 -60 130 -133c0 -126 -89 -213 -299 -213h-340l4 23h40c60 0 74 23 83 62l116 502c2 8 2 16 2 22c-2 24 -11 37 -56 37h-37zM440 624l-58 -251c12 -2 21 -2 32 -2 c14 0 28 1 40 4c74 16 109 76 109 150c0 35 -10 99 -74 99h-49zM373 324l-64 -274c19 -4 34 -5 52 -5c87 0 165 68 165 176c0 76 -53 103 -122 103h-31'],
  0x1D46A: [685,12,701,55,745,'745 685l-54 -234h-23c1 10 2 20 2 30c0 80 -45 157 -161 157c-183 0 -296 -200 -296 -375c0 -114 52 -218 173 -218c107 0 193 37 245 114l22 -15c-24 -39 -58 -70 -93 -96c-74 -54 -164 -60 -202 -60c-207 0 -303 119 -303 288c0 103 44 213 128 292 c79 74 188 117 311 117c61 0 129 -28 172 -28c9 0 40 0 57 28h22'],
  0x1D46B: [669,0,818,42,790,'197 669h289c214 0 304 -130 304 -275c0 -98 -38 -203 -116 -279c-72 -71 -177 -115 -309 -115h-323l4 23h37c59 0 76 21 85 60l116 504c2 8 3 16 3 23c0 22 -12 36 -57 36h-37zM440 624l-117 -508c-6 -24 -7 -29 -7 -32c2 -37 43 -39 78 -39c181 0 241 199 241 347 c0 90 -25 232 -140 232h-55'],
  0x1D46C: [669,0,732,42,754,'754 669l-40 -168h-23c3 17 3 28 3 38c-1 73 -75 85 -121 85h-135l-55 -239h55c56 0 116 9 137 95h22l-54 -251h-23c3 12 6 47 6 65c0 43 -56 46 -85 46h-69l-58 -258c-1 -6 -2 -13 -2 -17c0 -14 11 -20 42 -20h65c146 0 220 42 262 161h22l-61 -206h-600l4 23h36 c59 0 76 22 85 61l115 504c1 6 2 11 2 16c0 27 -17 42 -59 42h-37l4 23h562'],
  0x1D46D: [669,0,635,44,750,'750 669l-42 -168h-23c2 11 3 26 3 41c0 75 -79 82 -123 82h-124l-56 -248h59c57 0 119 8 138 96h24l-57 -253h-23c3 16 7 47 7 66c0 46 -56 46 -84 46h-75l-58 -249c-3 -9 -4 -17 -4 -24c0 -23 16 -35 60 -35h52l-3 -23h-377l4 23h36c62 0 76 22 85 61l116 504 c2 8 3 16 3 23c0 22 -13 35 -60 35h-37l4 23h555'],
  0x1D46E: [685,12,768,55,768,'768 342l-5 -23h-24c-60 0 -78 -19 -89 -61l-59 -218c-89 -43 -171 -52 -234 -52c-207 0 -302 138 -302 290c0 101 41 206 121 283c82 80 199 124 334 124c85 0 102 -33 162 -33c10 0 51 8 57 33h23l-53 -224h-23c4 14 6 27 6 40c0 76 -69 139 -166 139 c-188 0 -303 -212 -303 -398c0 -83 29 -209 156 -209c35 0 58 7 78 20l57 208c3 9 4 16 4 24c-1 23 -10 34 -55 34h-35l5 23h345'],
  0x1D46F: [669,0,891,42,946,'946 669l-5 -23h-37c-61 0 -75 -21 -84 -61l-114 -503c-2 -7 -6 -14 -6 -22v-3c1 -24 10 -34 58 -34h41l-5 -23h-349l4 23h23c61 0 78 22 87 61l57 251h-242l-59 -253c-1 -8 -4 -15 -4 -23c2 -27 14 -36 60 -36h25l-5 -23h-349l4 23h36c61 0 77 22 86 61l115 503 c2 8 3 14 3 21c0 23 -15 38 -57 38h-40l6 23h348l-3 -23h-25c-63 0 -76 -21 -85 -60l-46 -203h242l47 204c2 8 3 16 3 23c0 23 -14 36 -60 36h-37l3 23h364'],
  0x1D470: [669,0,502,42,557,'557 669l-4 -23h-38c-61 0 -76 -22 -85 -61l-116 -503c-1 -5 -1 -14 -1 -25c1 -23 12 -34 58 -34h37l-4 -23h-362l4 23h38c61 0 74 22 83 61l115 502c2 8 3 15 3 21c0 24 -15 39 -57 39h-37l4 23h362'],
  0x1D471: [669,12,558,66,646,'646 669l-3 -23h-37c-59 0 -78 -20 -87 -61l-96 -420c-16 -72 -49 -118 -95 -148c-37 -25 -92 -29 -118 -29c-79 0 -144 47 -144 101c0 34 20 78 85 78c41 0 81 -27 81 -58c0 -33 -27 -32 -27 -59c0 -16 15 -18 19 -18c22 0 37 67 43 93l105 463c2 8 3 15 3 22 c0 23 -15 36 -56 36h-38l3 23h362'],
  0x1D472: [669,0,795,42,839,'839 669l-4 -23c-56 0 -88 -25 -135 -63l-248 -201l191 -284c47 -69 76 -75 135 -75l-4 -23h-328l4 23h29c21 0 29 8 29 22c0 16 -11 33 -16 40l-138 208l-48 -211c-1 -5 -1 -14 -1 -21c1 -27 13 -38 58 -38h38l-5 -23h-354l5 23h30c63 0 73 22 82 61l115 503 c2 8 4 16 4 23c0 23 -15 36 -58 36h-37l4 23h347l-6 -23h-27c-58 0 -72 -26 -81 -64l-40 -178h2l243 198c9 8 15 16 15 23c0 11 -11 21 -31 21h-24l4 23h250'],
  0x1D473: [669,0,744,42,700,'700 199l-59 -199h-599l4 23h35c65 0 78 22 87 61l116 496c1 5 2 10 2 15c0 26 -18 51 -60 51h-36l4 23h360l-4 -23h-37c-53 0 -71 -23 -82 -70l-115 -492c-1 -5 -3 -13 -3 -16c1 -21 10 -23 21 -23h120c109 0 194 21 223 155'],
  0x1D474: [669,0,1016,42,1071,'1071 669l-3 -23h-34c-66 0 -80 -25 -89 -65l-115 -499c-2 -7 -3 -14 -3 -20c0 -25 16 -39 59 -39h39l-4 -23h-362l4 23h35c63 0 76 24 85 61l82 354h-1l-283 -438h-56l-90 441l-80 -348c-2 -10 -3 -27 -3 -40c2 -22 10 -30 55 -30h38l-3 -23h-300l4 23h36 c62 0 78 27 88 72l111 486c3 9 4 26 4 33c0 23 -16 32 -58 32h-39l4 23h246l91 -468l297 468h245'],
  0x1D475: [669,0,869,42,924,'924 669l-3 -23h-38c-61 0 -78 -22 -87 -64l-131 -582h-57l-263 491l-92 -409c-1 -6 -2 -11 -2 -18v-8c1 -23 12 -33 57 -33h39l-4 -23h-301l4 23h36c61 0 76 22 85 61l117 510c-17 43 -47 52 -71 52h-38l3 23h232l222 -435l80 350c2 7 2 14 2 20c0 24 -11 42 -57 42h-37 l4 23h300'],
  0x1D476: [685,16,777,55,755,'755 432c0 -237 -195 -448 -429 -448c-177 0 -271 120 -271 263c0 210 166 438 428 438c178 0 272 -124 272 -253zM601 467c0 88 -36 171 -129 171c-184 0 -262 -287 -262 -431c0 -91 36 -176 126 -176c168 0 265 279 265 436'],
  0x1D477: [669,0,612,42,733,'198 669h284c166 0 251 -45 251 -163c0 -97 -82 -206 -297 -206c-24 0 -46 0 -67 3l-51 -221c-1 -5 -4 -16 -4 -24c2 -27 13 -35 60 -35h52l-4 -23h-380l4 23h40c62 0 76 22 85 61l115 504c2 8 3 13 3 21c-1 24 -14 37 -60 37h-37zM441 623l-61 -273c13 -3 28 -5 40 -5 c91 0 157 72 157 176c0 52 -28 103 -106 103c-10 0 -21 0 -30 -1'],
  0x1D478: [685,154,810,55,755,'97 -112l159 101c-118 19 -201 119 -201 242c0 218 163 454 428 454c158 0 271 -103 272 -254c2 -230 -171 -430 -420 -449l-52 -30c8 1 17 1 23 1c72 0 165 -34 246 -34c34 0 88 2 145 68l17 -13c-57 -73 -132 -128 -258 -128c-56 0 -109 9 -146 17 c-50 11 -103 26 -129 26c-5 0 -30 -1 -72 -21zM601 479c0 114 -76 159 -129 159c-186 0 -262 -290 -262 -452c0 -63 36 -156 115 -156c183 0 276 278 276 449'],
  0x1D479: [669,0,801,42,784,'784 23l-4 -23h-223l-154 317c-5 0 -9 1 -35 2l-55 -237c-1 -5 -2 -14 -2 -22c2 -27 11 -37 56 -37h39l-4 -23h-360l4 23h36c65 0 75 22 84 61l114 500c2 10 4 19 4 27c0 23 -16 35 -59 35h-37l4 23h284c173 0 235 -72 235 -155c0 -81 -65 -149 -172 -176l115 -231 c23 -46 53 -84 130 -84zM379 364h40c101 0 139 64 139 142c0 82 -38 106 -72 114c-16 3 -25 4 -34 4h-16'],
  0x1D47A: [685,10,671,55,704,'704 682l-50 -219h-23c0 21 0 33 -1 50c-3 66 -73 125 -169 125c-36 0 -100 -21 -100 -84c0 -74 55 -118 113 -162c67 -51 126 -121 126 -210c0 -92 -94 -192 -257 -192c-65 0 -113 14 -157 32c-6 2 -29 9 -41 9c-15 0 -48 -9 -68 -39h-22l59 245h24v-35 c0 -86 63 -163 180 -163c94 0 135 54 135 119c0 41 -17 87 -43 113c-63 63 -194 131 -194 245c0 90 72 169 237 169c90 0 147 -40 179 -40c18 0 44 14 50 37h22'],
  0x1D47B: [669,0,568,28,700,'700 669l-44 -187h-24c6 18 7 40 7 54c0 62 -45 88 -111 88h-78l-123 -541c-1 -6 -4 -15 -4 -25c1 -24 11 -35 57 -35h42l-3 -23h-368l4 23h40c62 0 76 22 85 61l124 540h-75c-100 0 -160 -54 -179 -142h-22l43 187h629'],
  0x1D47C: [669,10,733,72,810,'810 669l-4 -23h-38c-61 0 -77 -18 -86 -60l-80 -359c-6 -25 -14 -55 -31 -92c-30 -65 -95 -145 -249 -145c-171 0 -240 100 -240 194c0 19 7 59 15 95l70 307c1 4 2 9 2 15c0 20 -10 45 -60 45h-37l4 23h363l-4 -23h-39c-65 0 -74 -19 -83 -60l-83 -363 c-4 -17 -7 -49 -7 -67c0 -56 45 -110 127 -110c96 0 145 77 170 187l79 355c2 5 2 16 2 24c-1 24 -13 34 -57 34h-37l4 23h299'],
  0x1D47D: [669,15,593,66,797,'797 669l-4 -23c-69 0 -104 -40 -132 -78l-431 -583h-52l-20 573c0 7 0 14 -1 20c-2 36 -9 68 -66 68h-25l3 23h326l-4 -23h-36c-42 0 -49 -37 -49 -69v-8l8 -350l242 336c18 25 33 52 33 71c0 15 -7 20 -34 20h-37l3 23h276'],
  0x1D47E: [669,17,925,66,1129,'1129 669l-3 -23c-72 0 -109 -49 -137 -87l-425 -576h-53l-21 407l-260 -407h-53l-21 575c-2 64 -12 88 -70 88h-20l3 23h314l-4 -23h-22c-36 0 -56 -16 -55 -78l8 -331l182 278l-3 65c-2 33 -13 66 -59 66h-24l4 23h318l-4 -23h-37c-45 0 -51 -42 -50 -78l5 -354 l242 331c16 22 34 56 34 79c0 17 -7 22 -35 22h-37l3 23h280'],
  0x1D47F: [669,0,808,28,830,'830 669l-3 -23h-24c-63 0 -82 -34 -116 -74l-177 -212l98 -270c15 -40 28 -67 62 -67h36l-4 -23h-316l3 23h28c33 0 49 12 49 36c0 8 -1 17 -5 27l-63 171l-154 -179c-6 -7 -8 -15 -8 -22c0 -18 15 -33 39 -33h42l-4 -23h-285l4 23c60 7 104 33 142 77l198 229l-89 237 c-12 33 -33 80 -84 80h-27l4 23h318l-4 -23h-39c-23 0 -34 -9 -34 -27c0 -9 4 -20 8 -32l53 -155l137 162c6 7 10 17 10 27c0 14 -8 25 -28 25h-31l4 23h260'],
  0x1D480: [669,0,549,39,725,'725 669l-3 -23c-58 0 -91 -33 -125 -76l-197 -252l-56 -236c-1 -9 -3 -16 -3 -27c0 -17 13 -32 58 -32h39l-4 -23h-362l4 23h37c63 0 75 24 84 61l56 243l-92 238c-20 51 -41 81 -122 81l3 23h331l-4 -23h-35c-33 0 -43 -11 -43 -28c0 -14 8 -36 15 -54l63 -172l150 191 c11 14 11 28 11 37c0 16 -13 26 -51 26h-28l4 23h270'],
  0x1D481: [669,0,797,66,830,'830 669l-548 -623h194c91 0 189 11 223 141h23l-44 -187h-612l555 624h-177c-87 0 -183 -4 -232 -121h-23l46 166h595'],
  0x1D482: [462,10,581,44,548,'529 105l19 -12c-36 -63 -79 -103 -155 -103c-35 0 -68 19 -69 70h-6c-47 -49 -99 -70 -146 -70c-71 0 -128 36 -128 122c0 139 116 350 281 350c55 0 82 -34 84 -64h2l11 51h115l-74 -316c-2 -7 -6 -28 -6 -45s4 -31 16 -31c19 0 35 21 56 48zM382 324 c0 64 -20 98 -54 98c-71 0 -168 -155 -168 -297c0 -55 27 -65 45 -65c70 0 177 153 177 264'],
  0x1D483: [685,8,509,50,487,'263 429l7 -1c26 17 56 31 93 31c92 0 124 -63 124 -163c0 -128 -101 -304 -273 -304c-58 0 -117 21 -164 55l127 563c1 5 2 10 2 14c0 11 -4 17 -14 17c-6 0 -15 0 -43 -7l-4 23l198 28zM219 253l-47 -203c3 -17 26 -23 37 -23c99 0 162 171 162 272c0 71 -26 96 -49 96 c-59 0 -92 -95 -103 -142'],
  0x1D484: [462,10,477,44,460,'412 114l18 -8c-51 -64 -123 -116 -224 -116c-126 0 -162 86 -162 162c0 132 110 310 294 310c72 0 122 -37 122 -82c0 -36 -23 -74 -78 -74c-44 0 -52 29 -52 43c0 36 23 32 23 53c0 15 -6 20 -15 20c-105 0 -178 -180 -178 -267c0 -92 50 -120 101 -120s98 22 151 79'],
  0x1D485: [685,14,595,44,589,'589 685l-130 -565c-3 -13 -8 -28 -8 -41s6 -24 24 -24s35 23 53 47l19 -11c-19 -46 -78 -105 -159 -105c-42 0 -66 37 -66 69h-5c-60 -62 -120 -69 -141 -69c-90 0 -132 51 -132 126c0 144 94 347 278 347c30 0 65 -8 85 -21l37 152c2 7 4 17 4 26c0 12 -4 22 -17 22 c-11 0 -29 -4 -42 -7l-4 23zM385 346c0 48 -31 73 -60 73c-78 0 -166 -153 -166 -297c0 -50 27 -67 48 -67c53 0 130 88 157 183c10 33 21 77 21 108'],
  0x1D486: [462,10,498,44,459,'412 114l19 -7c-53 -66 -113 -117 -229 -117c-123 0 -158 88 -158 158c0 20 1 38 6 59c43 174 178 255 286 255c44 0 123 -10 123 -84c0 -119 -181 -188 -295 -197c-4 -10 -4 -15 -4 -23c0 -82 44 -123 102 -123c57 0 91 22 150 79zM358 386c0 26 -8 36 -34 36 c-68 0 -144 -123 -153 -201c80 11 187 94 187 165'],
  0x1D487: [685,207,572,44,632,'249 449h52c37 0 40 54 70 117c26 54 81 119 167 119c65 0 94 -39 94 -77c0 -35 -19 -73 -60 -73c-43 0 -57 24 -57 49c0 37 20 30 20 51c0 4 -3 7 -10 7c-31 0 -56 -59 -70 -128l-13 -65h80l-12 -47h-79l-88 -387c-6 -27 -19 -66 -38 -104c-27 -52 -81 -118 -167 -118 c-65 0 -94 39 -94 77c0 35 19 73 60 73c43 0 57 -28 57 -53c0 -37 -20 -26 -20 -47c0 -4 3 -7 10 -7c47 0 72 164 86 225l78 341h-79'],
  0x1D488: [462,203,527,22,527,'527 435l-14 -60h-77c10 -15 13 -31 13 -48c0 -75 -52 -153 -154 -164c-50 -5 -74 -23 -74 -49c0 -53 231 -34 231 -155c0 -69 -68 -162 -229 -162c-145 0 -201 64 -201 118c0 55 54 95 119 118c-15 12 -22 33 -22 51c0 37 32 78 79 87c-68 22 -93 73 -93 115 c0 86 73 176 192 176c46 0 85 -19 98 -31zM334 361c0 38 -10 61 -32 61c-41 0 -79 -76 -79 -147c0 -48 12 -80 35 -80c51 0 76 106 76 166zM346 -81c0 49 -38 67 -90 78c-17 3 -55 11 -77 17l-17 -13c-16 -13 -38 -46 -38 -76c0 -49 36 -92 117 -92c74 0 105 40 105 86'],
  0x1D489: [685,10,576,50,543,'523 105l20 -11c-37 -63 -82 -104 -153 -104c-26 0 -69 15 -69 46c0 11 2 24 7 46l54 223c2 10 3 26 3 42c0 27 -13 37 -29 37c-57 0 -141 -165 -166 -275l-25 -109h-115l138 599c1 4 2 11 2 15c0 11 -1 15 -11 15c-7 0 -11 -1 -44 -10l-5 28l188 38l-81 -354l2 -1 c33 61 109 129 180 129c69 0 89 -38 89 -83c0 -13 -4 -44 -7 -56l-50 -213c-1 -4 -2 -15 -2 -21c0 -16 5 -28 20 -28c18 0 34 21 54 47'],
  0x1D48A: [620,9,357,55,300,'300 558c0 -30 -27 -62 -66 -62c-37 0 -66 32 -66 62c0 28 29 62 66 62c39 0 66 -34 66 -62zM255 104l19 -12c-32 -57 -82 -101 -152 -101c-51 0 -67 24 -67 56c0 10 1 20 4 31l66 285c3 13 5 20 5 27c0 11 -5 18 -20 18c-9 0 -21 0 -37 -3l-4 23l197 34l-78 -331 c-4 -15 -8 -30 -8 -48c0 -13 9 -25 21 -25c20 0 35 23 54 46'],
  0x1D48B: [620,207,431,-18,414,'414 558c0 -30 -27 -62 -66 -62c-37 0 -66 32 -66 62c0 28 29 62 66 62c39 0 66 -34 66 -62zM384 462l-102 -447c-6 -27 -17 -58 -36 -96c-27 -52 -84 -126 -170 -126c-65 0 -94 39 -94 77c0 35 19 73 60 73c36 0 57 -27 57 -53c0 -34 -21 -31 -21 -45c0 -9 5 -9 10 -9 c32 0 55 81 73 160l84 368c2 9 3 20 3 25c0 11 -5 18 -20 18c-9 0 -21 0 -37 -3l-4 23'],
  0x1D48C: [685,11,580,55,563,'563 449l-6 -19c-72 -9 -95 -30 -132 -66l-95 -94l64 -149c16 -37 32 -57 40 -57c14 0 33 5 51 67h25c0 -20 -37 -142 -120 -142c-61 0 -72 44 -92 82l-64 124l-24 -22l-39 -173h-116l138 601c1 3 2 9 2 16c0 9 -4 13 -11 13c-6 0 -13 -2 -44 -9l-5 27l193 37l-97 -423 l124 111c7 6 24 28 24 43c0 7 -7 12 -17 12h-30l7 21h224'],
  0x1D48D: [685,9,346,50,310,'310 685l-132 -574c-3 -11 -4 -22 -4 -31c1 -6 7 -14 18 -14c18 0 32 11 52 37l19 -15c-24 -38 -85 -97 -153 -97c-32 0 -60 16 -60 46c0 11 1 26 6 47l118 515c1 6 2 11 2 16c0 12 -4 15 -11 15c-9 0 -27 -5 -44 -10l-5 28'],
  0x1D48E: [467,9,760,33,727,'708 106l19 -15c-30 -52 -78 -100 -157 -100c-26 0 -60 17 -61 48c0 21 5 39 11 66l46 202c3 14 9 52 9 60c0 10 0 22 -16 22c-35 0 -134 -183 -148 -249l-29 -140h-119l73 307c4 18 8 53 8 60c-1 13 -4 21 -18 21c-36 0 -129 -183 -144 -248l-32 -140h-117l89 388 c0 20 -4 26 -12 26c-6 0 -13 -1 -45 -9l-5 28l197 34l-27 -111h2c66 91 119 106 153 106c53 0 76 -47 77 -85c0 -7 -1 -14 -2 -19c41 48 89 104 156 104c52 0 75 -35 75 -77c0 -19 -2 -42 -8 -68l-41 -186c-3 -14 -8 -32 -8 -46s5 -24 23 -24c17 0 39 27 51 45'],
  0x1D48F: [467,10,559,33,526,'506 105l20 -11c-37 -63 -82 -104 -153 -104c-46 0 -68 23 -68 58c0 10 3 22 6 34l54 223c2 10 3 31 3 47c0 27 -13 35 -29 35c-57 0 -141 -168 -166 -278l-25 -109h-115l88 384c1 4 2 11 2 15c0 11 -1 15 -11 15c-7 0 -14 0 -47 -9l-5 28l195 34l-27 -111h4 c33 61 99 106 170 106c69 0 89 -36 89 -81c0 -13 -4 -49 -7 -61l-50 -213c-1 -6 -3 -14 -3 -22c0 -14 4 -27 21 -27c18 0 34 21 54 47'],
  0x1D490: [462,10,561,44,539,'539 297c0 -186 -144 -307 -308 -307c-118 0 -187 71 -187 180c0 172 139 292 295 292c118 0 200 -58 200 -165zM423 300c0 91 -43 122 -89 122c-88 0 -174 -151 -174 -264c0 -97 28 -128 88 -128c92 0 175 142 175 270'],
  0x1D491: [469,205,571,-33,554,'294 429h5c26 24 61 33 91 33c78 0 164 -42 164 -171c0 -165 -141 -303 -273 -303c-29 0 -68 6 -88 19l-25 -105c-3 -12 -4 -21 -4 -32c0 -26 7 -54 41 -54h36l-7 -21h-267l7 21c56 8 66 43 77 89l103 440c3 15 5 28 5 39c0 20 -7 32 -23 32c-6 0 -14 -1 -25 -4l-6 17 l198 40zM244 241l-33 -154c1 -44 34 -59 67 -59c73 0 162 141 162 261c0 94 -29 123 -77 123c-53 0 -100 -83 -119 -171'],
  0x1D492: [462,205,526,44,532,'532 449l-129 -561c-2 -7 -5 -18 -5 -27c1 -34 11 -45 32 -45h34l-6 -21h-288l6 21h36c51 0 65 34 74 72l38 168h-1c-41 -57 -122 -66 -153 -66c-81 0 -126 65 -126 136c0 152 105 336 278 336c34 0 70 -13 85 -51h4l10 38h111zM388 345c0 53 -32 77 -61 77 c-90 0 -169 -160 -169 -305c0 -29 8 -70 53 -70c69 0 177 145 177 298'],
  0x1D493: [467,0,441,33,424,'257 467l-20 -91c29 44 71 86 125 86c42 0 62 -29 62 -55c0 -36 -25 -86 -81 -86c-41 0 -33 38 -49 38c-42 0 -121 -255 -127 -279l-20 -80h-114l88 380c1 8 3 15 3 21c0 12 -9 15 -16 15c-10 0 -19 -3 -41 -11l-3 28'],
  0x1D494: [462,11,474,55,419,'419 462l-22 -160h-22c-1 73 -50 123 -88 123c-27 0 -46 -13 -46 -55c0 -29 34 -62 68 -102c42 -50 75 -81 75 -149c0 -66 -56 -129 -155 -129c-60 0 -84 21 -110 21c-11 0 -24 -7 -39 -22h-25l22 165h24c2 -71 59 -128 106 -128c46 0 63 39 63 80c0 39 -29 64 -47 85 c-40 47 -91 100 -91 154c0 81 69 117 130 117c56 0 76 -22 93 -22c9 0 30 2 39 22h25'],
  0x1D495: [592,10,351,44,318,'318 460l-12 -47h-67l-69 -302c-1 -5 -3 -14 -3 -19c0 -19 7 -32 20 -32c18 0 35 17 54 44l20 -10c-31 -58 -88 -104 -151 -104c-37 0 -66 17 -66 61c0 10 1 22 4 33l76 329h-74l8 47c118 0 134 44 167 132h54l-29 -132h68'],
  0x1D496: [463,10,535,33,502,'482 104l20 -10c-38 -67 -85 -104 -155 -104c-26 0 -66 15 -67 47c0 13 0 38 17 82h-3c-28 -45 -87 -129 -182 -129c-63 0 -79 40 -79 82c0 20 3 40 7 57l54 237c2 11 3 22 3 25c0 18 -6 21 -13 21c-4 0 -14 -1 -44 -7l-3 24l194 34l-79 -344c-2 -6 -6 -23 -6 -32 c0 -18 9 -22 21 -22c48 0 166 180 190 294l19 90h113l-78 -337c-1 -5 -2 -12 -2 -19c0 -17 4 -35 19 -35c18 0 35 20 54 46'],
  0x1D497: [473,14,554,52,539,'60 412v24c78 3 154 20 229 37c-13 -40 -22 -81 -34 -121c-17 -59 -62 -188 -62 -243c0 -31 22 -42 50 -42c66 0 181 146 198 207c3 11 5 22 5 34c0 52 -47 48 -47 105c0 33 31 60 63 60c41 0 77 -36 77 -77c0 -34 -22 -79 -38 -109c-51 -95 -133 -198 -223 -258 c-37 -25 -85 -43 -130 -43c-50 0 -96 23 -96 79c0 86 42 197 65 281c3 13 7 26 7 39c0 29 -44 27 -64 27'],
  0x1D498: [473,14,814,52,799,'565 462l-76 -279c-7 -25 -20 -61 -20 -87c0 -22 14 -29 34 -29c56 0 129 91 159 134c23 32 44 66 44 106c0 59 -47 47 -47 107c0 32 31 59 63 59c42 0 77 -35 77 -76c0 -34 -22 -80 -38 -109c-50 -94 -136 -202 -224 -260c-36 -24 -85 -42 -129 -42c-58 0 -74 29 -74 83 c0 25 16 67 24 91c-45 -80 -112 -174 -214 -174c-51 0 -92 25 -92 81c0 37 7 74 17 110l37 134c6 21 18 55 18 76c0 24 -31 26 -49 26h-15v24c78 5 155 17 230 36l-91 -312c-6 -22 -14 -45 -14 -68c0 -15 6 -29 24 -29c65 0 132 134 154 186c29 69 46 141 64 212h138'],
  0x1D499: [462,8,587,33,543,'327 334l22 34c22 34 65 94 122 94c47 0 72 -27 72 -50c0 -22 -5 -66 -62 -66c-30 0 -26 34 -40 34s-20 -10 -38 -40l-47 -79l49 -138c7 -19 13 -54 33 -54c17 0 34 5 55 68h24c-21 -81 -57 -145 -119 -145c-59 0 -78 44 -92 81l-29 75l-36 -62c-26 -44 -64 -94 -130 -94 c-50 0 -78 28 -78 60s20 58 60 58c47 0 31 -45 49 -45c11 0 21 15 49 59l61 97l-33 91c-21 57 -41 91 -80 91c-7 0 -14 0 -52 -15l-8 24l153 50c59 -34 80 -82 89 -109'],
  0x1D49A: [462,205,519,35,522,'330 128h1c20 29 43 68 61 102c21 39 46 92 46 107c0 30 -46 12 -46 71c0 19 27 54 60 54c46 0 70 -22 70 -75c0 -78 -155 -336 -196 -397c-69 -103 -128 -195 -213 -195c-56 0 -76 34 -77 58s8 66 60 66c42 0 39 -49 54 -49c13 0 66 69 86 118l-53 317 c-8 47 -17 106 -50 106c-5 0 -24 -3 -51 -8l-4 24l170 33c25 -21 49 -93 56 -142'],
  0x1D49B: [462,19,531,35,499,'499 452l-318 -337l1 -1c13 3 26 4 39 4c77 0 113 -107 144 -107c13 0 18 7 18 19c0 16 -20 26 -20 52c0 31 25 59 57 59c33 0 61 -28 61 -61c0 -76 -70 -99 -135 -99c-67 0 -133 24 -200 24c-33 0 -63 -7 -93 -19l-18 25l321 340h-165c-46 0 -59 -7 -74 -51l-24 3 l46 159h360v-10'],
  0x1D71C: [685,0,759,39,724,'724 23l-2 -23h-319l4 23h31c33 0 51 17 51 45c0 10 -1 28 -2 34l-15 108h-159l-80 -139c-2 -4 -6 -13 -6 -22c0 -19 9 -26 22 -26h56l-6 -23h-260l4 23c45 5 74 17 108 75l346 587h49l94 -624c4 -24 20 -38 47 -38h37zM466 256l-23 178l-103 -178h126'],
  0x1D71D: [669,0,726,42,715,'197 669h265c124 0 253 -22 253 -152c0 -74 -43 -120 -100 -147c-18 -9 -43 -18 -64 -24c58 -11 130 -60 130 -133c0 -126 -89 -213 -299 -213h-340l4 23h40c60 0 74 23 83 62l116 502c2 8 2 16 2 22c-2 24 -11 37 -56 37h-37zM440 624l-58 -251c12 -2 21 -2 32 -2 c14 0 28 1 40 4c74 16 109 76 109 150c0 35 -10 99 -74 99h-49zM373 324l-64 -274c19 -4 34 -5 52 -5c87 0 165 68 165 176c0 76 -53 103 -122 103h-31'],
  0x1D71E: [669,0,634,42,749,'749 669l-43 -184h-23c4 19 5 36 5 50c0 66 -49 89 -94 89h-155l-125 -542c-2 -10 -3 -18 -3 -25c0 -25 17 -34 59 -34h52l-5 -23h-375l4 23h36c61 0 76 22 85 61l115 503c2 10 3 29 3 37c-1 20 -17 22 -56 22h-38l3 23h555'],
  0x1D71F: [685,0,632,32,589,'589 0h-557l405 685h48zM427 102l-44 332l-192 -332h236'],
  0x1D720: [669,0,732,42,754,'754 669l-40 -168h-23c3 17 3 28 3 38c-1 73 -75 85 -121 85h-135l-55 -239h55c56 0 116 9 137 95h22l-54 -251h-23c3 12 6 47 6 65c0 43 -56 46 -85 46h-69l-58 -258c-1 -6 -2 -13 -2 -17c0 -14 11 -20 42 -20h65c146 0 220 42 262 161h22l-61 -206h-600l4 23h36 c59 0 76 22 85 61l115 504c1 6 2 11 2 16c0 27 -17 42 -59 42h-37l4 23h562'],
  0x1D721: [669,0,797,66,830,'830 669l-548 -623h194c91 0 189 11 223 141h23l-44 -187h-612l555 624h-177c-87 0 -183 -4 -232 -121h-23l46 166h595'],
  0x1D722: [669,0,891,42,946,'946 669l-5 -23h-37c-61 0 -75 -21 -84 -61l-114 -503c-2 -7 -6 -14 -6 -22v-3c1 -24 10 -34 58 -34h41l-5 -23h-349l4 23h23c61 0 78 22 87 61l57 251h-242l-59 -253c-1 -8 -4 -15 -4 -23c2 -27 14 -36 60 -36h25l-5 -23h-349l4 23h36c61 0 77 22 86 61l115 503 c2 8 3 14 3 21c0 23 -15 38 -57 38h-40l6 23h348l-3 -23h-25c-63 0 -76 -21 -85 -60l-46 -203h242l47 204c2 8 3 16 3 23c0 23 -14 36 -60 36h-37l3 23h364'],
  0x1D723: [685,16,783,55,755,'533 440h23c-31 -67 -43 -126 -43 -199h-23v15c0 26 -10 41 -30 41h-115c-29 0 -38 -5 -64 -56h-23c33 64 45 125 45 199h22c0 -45 12 -57 39 -57h116c23 0 34 12 53 57zM755 430c0 -228 -195 -446 -429 -446c-177 0 -271 118 -271 261c0 196 166 440 428 440 c178 0 272 -126 272 -255zM601 465c0 88 -36 173 -129 173c-184 0 -262 -289 -262 -433c0 -91 36 -174 126 -174c168 0 265 277 265 434'],
  0x1D724: [669,0,502,42,557,'557 669l-4 -23h-38c-61 0 -76 -22 -85 -61l-116 -503c-1 -5 -1 -14 -1 -25c1 -23 12 -34 58 -34h37l-4 -23h-362l4 23h38c61 0 74 22 83 61l115 502c2 8 3 15 3 21c0 24 -15 39 -57 39h-37l4 23h362'],
  0x1D725: [669,0,795,42,839,'839 669l-4 -23c-56 0 -88 -25 -135 -63l-248 -201l191 -284c47 -69 76 -75 135 -75l-4 -23h-328l4 23h29c21 0 29 8 29 22c0 16 -11 33 -16 40l-138 208l-48 -211c-1 -5 -1 -14 -1 -21c1 -27 13 -38 58 -38h38l-5 -23h-354l5 23h30c63 0 73 22 82 61l115 503 c2 8 4 16 4 23c0 23 -15 36 -58 36h-37l4 23h347l-6 -23h-27c-58 0 -72 -26 -81 -64l-40 -178h2l243 198c9 8 15 16 15 23c0 11 -11 21 -31 21h-24l4 23h250'],
  0x1D726: [685,0,759,39,724,'724 23l-2 -23h-319l4 23h31c33 0 51 17 51 45c0 10 -1 28 -2 34l-44 332l-210 -363c-2 -4 -6 -13 -6 -22c0 -19 9 -26 22 -26h56l-6 -23h-260l4 23c45 5 74 17 108 75l346 587h49l94 -624c4 -24 20 -38 47 -38h37'],
  0x1D727: [669,0,1016,42,1071,'1071 669l-3 -23h-34c-66 0 -80 -25 -89 -65l-115 -499c-2 -7 -3 -14 -3 -20c0 -25 16 -39 59 -39h39l-4 -23h-362l4 23h35c63 0 76 24 85 61l82 354h-1l-283 -438h-56l-90 441l-80 -348c-2 -10 -3 -27 -3 -40c2 -22 10 -30 55 -30h38l-3 -23h-300l4 23h36 c62 0 78 27 88 72l111 486c3 9 4 26 4 33c0 23 -16 32 -58 32h-39l4 23h246l91 -468l297 468h245'],
  0x1D728: [669,0,869,42,924,'924 669l-3 -23h-38c-61 0 -78 -22 -87 -64l-131 -582h-57l-263 491l-92 -409c-1 -6 -2 -11 -2 -18v-8c1 -23 12 -33 57 -33h39l-4 -23h-301l4 23h36c61 0 76 22 85 61l117 510c-17 43 -47 52 -71 52h-38l3 23h232l222 -435l80 350c2 7 2 14 2 20c0 24 -11 42 -57 42h-37 l4 23h300'],
  0x1D729: [669,0,718,57,757,'757 669l-38 -182h-23c3 11 4 21 4 30c0 30 -15 46 -53 46h-337c-42 0 -82 -26 -93 -76h-23l38 182h525zM635 459l-51 -239h-23c3 12 4 22 4 31c-1 26 -18 36 -45 36h-204c-57 0 -63 -19 -74 -67h-23l51 239h23c-3 -13 -5 -23 -5 -32c0 -27 15 -34 49 -34h203 c39 0 60 13 72 66h23zM663 187l-39 -187h-567l39 187h23c-2 -8 -4 -18 -4 -25c0 -39 28 -50 71 -50h349c69 0 92 16 105 75h23'],
  0x1D72A: [685,16,777,55,755,'755 432c0 -237 -195 -448 -429 -448c-177 0 -271 120 -271 263c0 210 166 438 428 438c178 0 272 -124 272 -253zM601 467c0 88 -36 171 -129 171c-184 0 -262 -287 -262 -431c0 -91 36 -176 126 -176c168 0 265 279 265 436'],
  0x1D72B: [669,0,887,39,942,'942 669l-5 -23h-37c-61 0 -75 -20 -84 -60l-115 -504c-2 -10 -4 -19 -4 -26c0 -23 13 -33 58 -33h40l-5 -23h-349l5 23h22c60 0 75 11 86 61l123 540h-242l-124 -542c-2 -10 -3 -19 -3 -26c0 -31 23 -33 59 -33h25l-5 -23h-348l5 23h35c58 0 75 19 85 61l115 504 c2 10 2 29 3 36c0 10 -18 22 -57 22h-40l5 23h752'],
  0x1D72C: [669,0,612,42,733,'198 669h284c166 0 251 -45 251 -163c0 -97 -82 -206 -297 -206c-24 0 -46 0 -67 3l-51 -221c-1 -5 -4 -16 -4 -24c2 -27 13 -35 60 -35h52l-4 -23h-380l4 23h40c62 0 76 22 85 61l115 504c2 8 3 13 3 21c-1 24 -14 37 -60 37h-37zM441 623l-61 -273c13 -3 28 -5 40 -5 c91 0 157 72 157 176c0 52 -28 103 -106 103c-10 0 -21 0 -30 -1'],
  0x1D72D: [685,16,783,55,755,'755 430c0 -228 -195 -446 -429 -446c-177 0 -271 118 -271 261c0 196 166 440 428 440c178 0 272 -126 272 -255zM237 383h356c5 29 8 57 8 82c0 88 -36 173 -129 173c-122 0 -198 -128 -235 -255zM574 297h-356c-6 -34 -8 -66 -8 -92c0 -91 36 -174 126 -174 c116 0 198 132 238 266'],
  0x1D72E: [669,0,759,64,787,'787 669l-39 -168h-23c3 17 3 33 3 50c0 66 -55 73 -108 73h-212l159 -250l-286 -266h270c82 0 122 19 161 92h25l-76 -200h-597l372 338l-217 331h568'],
  0x1D72F: [669,0,568,28,700,'700 669l-44 -187h-24c6 18 7 40 7 54c0 62 -45 88 -111 88h-78l-123 -541c-1 -6 -4 -15 -4 -25c1 -24 11 -35 57 -35h42l-3 -23h-368l4 23h40c62 0 76 22 85 61l124 540h-75c-100 0 -160 -54 -179 -142h-22l43 187h629'],
  0x1D730: [685,0,641,31,784,'784 629l-20 -22c-11 10 -28 24 -44 24c-47 0 -143 -130 -174 -167l-121 -145l-54 -233c-2 -9 -4 -19 -4 -29c0 -34 31 -34 57 -34h40l-6 -23h-361l8 23h36c39 0 66 6 78 57l59 248l-74 190c-14 37 -43 96 -89 96c-26 0 -44 -12 -64 -27l-20 21c42 53 82 77 151 77 c66 0 123 -37 145 -100l67 -192l157 189c36 43 94 95 154 95c27 0 66 -26 79 -48'],
  0x1D731: [669,0,827,28,799,'546 587l-5 -24c124 0 258 -48 258 -173c0 -202 -243 -286 -364 -286h-1l-7 -32c-1 -6 -1 -15 -1 -19c0 -22 16 -30 52 -30h47l-5 -23h-365l6 23c76 0 108 6 116 44l8 37c-134 0 -257 59 -257 189c0 189 211 270 363 270l10 44c1 2 1 5 1 7c0 18 -22 32 -58 32h-41l5 23 h364l-5 -23h-41c-56 0 -72 -23 -80 -59zM529 517l-85 -366c79 0 192 109 192 229c0 71 -40 137 -107 137zM298 151l85 366c-89 0 -197 -132 -197 -232c0 -78 45 -134 112 -134'],
  0x1D732: [669,0,808,28,830,'830 669l-3 -23h-24c-63 0 -82 -34 -116 -74l-177 -212l98 -270c15 -40 28 -67 62 -67h36l-4 -23h-316l3 23h28c33 0 49 12 49 36c0 8 -1 17 -5 27l-63 171l-154 -179c-6 -7 -8 -15 -8 -22c0 -18 15 -33 39 -33h42l-4 -23h-285l4 23c60 7 104 33 142 77l198 229l-89 237 c-12 33 -33 80 -84 80h-27l4 23h318l-4 -23h-39c-23 0 -34 -9 -34 -27c0 -9 4 -20 8 -32l53 -155l137 162c6 7 10 17 10 27c0 14 -8 25 -28 25h-31l4 23h260'],
  0x1D733: [685,0,694,30,781,'781 684l-5 -23c-53 0 -68 -88 -77 -127c-12 -52 -24 -113 -55 -158c-59 -86 -156 -112 -255 -112l-39 -171c-3 -12 -6 -24 -6 -36c0 -31 49 -34 80 -34h17l-5 -23h-362l5 23h23c60 0 87 10 101 72l39 169c-88 0 -210 42 -210 147c0 65 37 123 37 188c0 23 -11 62 -39 63 l5 23h33c86 0 126 -61 126 -141c0 -35 -7 -69 -17 -102c-6 -20 -13 -41 -13 -63c0 -51 45 -66 89 -68l62 271c2 7 3 14 3 21c0 39 -39 44 -72 44c-9 0 -18 0 -25 -1l6 23h362l-6 -23c-57 0 -104 3 -120 -64l-63 -271c60 0 101 32 124 85c21 47 24 100 41 149 c32 88 85 139 183 139h33'],
  0x1D734: [685,0,826,57,815,'300 92l6 31c-100 18 -158 89 -158 185c0 158 143 377 401 377c181 0 266 -109 266 -247c0 -159 -126 -279 -275 -315l-9 -31h153c31 0 50 28 63 75h23l-38 -167h-305l42 153c110 24 189 182 189 310c0 84 -36 174 -120 174c-130 0 -231 -194 -231 -345 c0 -71 25 -124 83 -139l-28 -153h-305l38 167h23c-3 -15 -5 -28 -5 -38c0 -27 10 -37 41 -37h146'],
  0x1D735: [669,16,632,43,600,'600 669l-405 -685h-48l-104 685h557zM441 567h-236l44 -332'],
  0x1D736: [461,12,624,44,630,'630 449l-163 -258s-1 -6 -1 -12c0 -8 0 -17 1 -23c7 -80 27 -98 41 -98c21 0 43 26 58 76l24 -7c-19 -77 -56 -139 -121 -139c-46 0 -82 41 -89 79c-56 -60 -112 -77 -181 -77c-93 0 -155 57 -155 168c0 149 114 303 276 303c77 0 120 -49 136 -99l49 87h125zM369 280 c0 70 -15 141 -62 141c-49 0 -147 -116 -147 -278c0 -59 18 -116 57 -116c53 0 119 106 146 178c4 22 6 48 6 75'],
  0x1D737: [685,205,555,28,583,'54 -114l114 487c33 143 84 216 165 274c39 28 72 38 129 38c67 0 121 -50 121 -118c0 -76 -46 -146 -113 -173v-2c45 -7 88 -41 88 -126c0 -123 -89 -278 -262 -278c-33 0 -74 4 -97 18l-28 -124c-7 -32 -17 -66 -26 -87h-117c9 21 19 61 26 91zM304 480l-87 -393 c0 -44 35 -59 67 -59c90 0 156 131 156 227c0 106 -34 117 -52 117c-17 0 -30 -6 -45 -6c-27 0 -33 14 -33 25c0 16 16 36 56 36c13 0 49 -11 58 -11c38 0 56 82 56 132c0 56 -29 85 -62 85c-67 0 -93 -57 -114 -153'],
  0x1D738: [462,203,490,44,503,'503 449l-264 -401c0 -77 -19 -251 -113 -251c-44 0 -57 39 -57 61c0 58 53 122 91 185c10 73 13 153 13 208c0 41 -8 141 -45 141c-18 0 -42 -14 -61 -81h-23c18 67 54 151 121 151c71 0 84 -65 84 -135c0 -33 -4 -92 -7 -125l135 247h126'],
  0x1D739: [685,8,538,44,538,'44 169v1c0 114 95 238 237 261c-55 28 -104 73 -104 124c0 91 98 130 192 130c53 0 142 -20 142 -63c0 -29 -11 -62 -59 -62c-70 0 -64 81 -132 81c-26 0 -68 -4 -68 -56c0 -90 286 -109 286 -295c0 -169 -143 -298 -308 -298c-117 0 -186 67 -186 177zM422 259 c0 82 -77 134 -107 134c-93 -23 -155 -124 -155 -238c0 -95 27 -123 88 -123c95 0 174 139 174 227'],
  0x1D73A: [462,10,495,28,451,'451 389l-18 -7c-17 20 -34 40 -103 40s-127 -48 -127 -108c0 -32 24 -51 60 -51c13 0 45 9 74 9c19 0 47 -4 47 -22c0 -23 -17 -37 -65 -37c-11 0 -42 6 -59 6c-43 0 -116 -39 -116 -109c0 -52 47 -75 101 -75c59 0 97 22 151 79l18 -8c-51 -64 -122 -116 -224 -116 c-99 0 -162 50 -162 108c0 64 43 119 108 142v3c-30 10 -49 42 -49 67c0 78 81 152 227 152c65 0 124 -35 137 -73'],
  0x1D73B: [685,203,472,44,522,'330 685l7 -21c-56 -21 -80 -55 -80 -76c0 -28 19 -38 31 -41c42 37 127 104 186 104c36 0 48 -12 48 -30c0 -49 -105 -129 -199 -129c-90 -60 -173 -178 -173 -313c0 -57 39 -86 100 -86c94 0 156 -30 156 -93c0 -47 -28 -97 -74 -138c-34 -30 -85 -65 -121 -65 c-53 0 -77 32 -77 63c0 21 6 54 61 54c46 0 31 -42 62 -42c39 0 73 31 73 80c0 33 -19 46 -62 46c-12 0 -54 -7 -73 -7c-84 0 -151 61 -151 147c0 132 69 247 206 372c-35 5 -74 26 -74 59c0 49 45 96 154 116'],
  0x1D73C: [462,205,517,33,511,'248 356l6 1c33 61 97 105 168 105c69 0 89 -30 89 -75c0 -18 -4 -45 -8 -64l-76 -325c-12 -50 -22 -149 -22 -182c0 -13 1 -9 6 -21h-113c-11 21 -13 34 -13 52c0 41 18 126 100 467c1 5 3 22 3 38c0 27 -13 35 -29 35c-57 0 -140 -168 -166 -277l-26 -110h-115l74 318 c3 13 6 34 6 52c0 17 -8 22 -18 22c-20 0 -42 -22 -61 -45l-20 12c34 52 95 103 161 103c48 0 60 -25 60 -47c0 -21 -2 -32 -6 -59'],
  0x1D73D: [685,11,566,44,555,'555 476c0 -262 -174 -487 -343 -487c-108 0 -168 89 -168 226c0 237 163 471 330 470c109 0 181 -73 181 -209zM184 359h243c8 41 13 89 13 128c0 116 -17 158 -66 158c-80 0 -156 -140 -190 -286zM417 315h-245c-10 -47 -15 -93 -15 -132c0 -111 27 -154 70 -154 c81 0 151 143 190 286'],
  0x1D73E: [462,9,318,55,274,'255 104l19 -12c-32 -57 -82 -101 -152 -101c-51 0 -67 24 -67 56c0 10 1 20 4 31l64 276c3 13 6 29 6 36c0 11 -5 18 -20 18c-9 0 -21 0 -37 -3l-4 23l197 34l-77 -331c-3 -15 -8 -30 -8 -48c0 -13 9 -25 21 -25c20 0 35 23 54 46'],
  0x1D73F: [462,0,560,55,577,'240 294l129 101c34 27 86 67 140 67c42 0 68 -17 68 -50c0 -28 -11 -62 -59 -62c-52 0 -36 46 -72 46c-9 0 -32 -15 -49 -29l-114 -93l112 -199c25 -44 51 -52 103 -52l-5 -23h-269l5 23h29c16 0 28 2 28 15c0 9 -7 26 -13 36l-60 107l-42 -181h-116l82 363 c3 12 4 21 4 28c0 15 -12 17 -26 17c-10 0 -21 -1 -32 -3l-3 23l196 34'],
  0x1D740: [685,16,570,55,537,'514 130h23c-15 -73 -54 -146 -128 -146c-48 0 -69 48 -69 117c0 48 10 98 19 174l-192 -275h-112l302 435v50c0 95 -24 130 -55 130c-22 0 -45 -27 -60 -77h-23c20 74 55 147 125 147c52 0 55 -71 55 -146v-387c0 -79 32 -98 55 -98c21 0 45 26 60 76'],
  0x1D741: [449,205,636,33,603,'583 83l20 -12c-37 -66 -84 -103 -161 -103c-42 0 -57 31 -57 61c0 26 9 56 16 78l-3 1c-29 -55 -87 -110 -135 -110c-29 0 -43 8 -55 27h-2c-34 -132 -46 -193 -70 -230h-103c14 23 32 72 48 138l122 516h113l-74 -316c-2 -8 -3 -16 -3 -23c1 -29 11 -37 40 -37 c69 0 151 156 186 294l21 82h111l-79 -338c-4 -16 -7 -30 -7 -44c0 -18 5 -31 19 -31c18 0 39 26 53 47'],
  0x1D742: [459,10,523,55,534,'510 455l24 -7c-44 -181 -167 -325 -291 -458h-52l-58 378c-4 28 -37 34 -76 34l-2 23c44 2 103 6 182 34l45 -315h1c146 142 197 246 227 311'],
  0x1D743: [685,203,476,28,487,'332 685l6 -23c-64 -26 -79 -53 -79 -73c0 -21 15 -29 16 -32c40 37 112 74 158 74c26 0 54 -5 54 -29c0 -57 -90 -91 -175 -91c-46 0 -66 -40 -66 -78c0 -17 5 -29 14 -43c40 23 94 39 134 39c33 0 74 -3 74 -31c0 -62 -102 -69 -140 -69c-20 0 -44 3 -64 8 c-65 -28 -134 -86 -134 -172c0 -53 29 -71 100 -71c127 0 187 -25 187 -94c0 -47 -28 -97 -67 -134c-35 -33 -85 -69 -128 -69c-53 0 -77 32 -77 65c0 30 19 52 59 52c47 0 36 -43 65 -43c43 0 72 40 72 82c0 33 -20 45 -61 45c-20 0 -48 -7 -70 -7c-105 0 -182 34 -182 121 c0 103 74 185 174 249c-22 21 -28 41 -28 75c0 29 29 70 59 85v3c-31 4 -53 27 -53 56c0 51 49 85 152 105'],
  0x1D744: [462,10,561,44,539,'539 297c0 -186 -144 -307 -308 -307c-118 0 -187 71 -187 180c0 172 139 292 295 292c118 0 200 -58 200 -165zM423 300c0 91 -43 122 -89 122c-88 0 -174 -151 -174 -264c0 -97 28 -128 88 -128c92 0 175 142 175 270'],
  0x1D745: [449,13,579,39,590,'590 449l-21 -91h-113c-17 -47 -53 -171 -53 -234c0 -25 10 -61 34 -61c16 0 42 12 65 71l24 -6c-15 -65 -75 -135 -157 -135c-56 0 -73 41 -73 83c0 22 4 45 7 61c16 75 40 140 62 221h-61c-44 -119 -64 -371 -194 -371c-44 0 -71 17 -71 51c0 23 9 39 42 51 c31 11 48 39 58 68l71 201c-40 0 -81 -6 -118 -54h-23c54 95 110 145 223 145h298'],
  0x1D746: [462,205,595,33,562,'58 -110l62 267c34 145 101 230 162 270c35 23 81 35 115 35c78 0 165 -50 165 -180c0 -164 -141 -294 -274 -294c-30 0 -66 7 -87 19l-25 -110c-6 -28 -18 -77 -28 -102h-115c8 21 19 69 25 95zM252 240l-33 -152c1 -43 34 -60 68 -60c72 0 161 133 161 253 c0 93 -31 131 -76 131c-55 0 -101 -82 -120 -172'],
  0x1D747: [462,203,480,39,508,'508 388c0 -24 -22 -53 -56 -53c-56 0 -49 47 -97 47c-102 0 -214 -98 -214 -217c0 -53 29 -71 100 -71c127 0 187 -25 187 -94c0 -47 -28 -106 -67 -143c-35 -33 -85 -60 -128 -60c-53 0 -77 32 -77 65c0 30 19 52 59 52c47 0 36 -43 65 -43c43 0 72 40 72 82 c0 33 -20 45 -61 45c-20 0 -48 -7 -70 -7c-105 0 -182 34 -182 121c0 103 75 213 174 279c54 36 128 71 192 71c60 0 103 -27 103 -74'],
  0x1D748: [449,10,592,44,603,'603 449l-21 -91h-176c24 -54 101 -50 101 -147c0 -120 -126 -221 -275 -221c-120 0 -188 68 -188 177c0 139 112 282 311 282h248zM391 207v1c0 81 -24 118 -59 150c-82 0 -172 -70 -172 -203c0 -97 29 -125 88 -125c81 0 143 94 143 177'],
  0x1D749: [449,7,469,33,502,'502 449l-21 -91h-149l-53 -188c-5 -18 -8 -38 -8 -56c0 -28 9 -51 32 -51c16 0 42 12 67 71l22 -6c-14 -65 -79 -135 -149 -135c-45 0 -89 18 -89 70c0 34 6 71 15 100l59 195h-32c-43 0 -109 -29 -140 -89h-23c25 67 107 180 214 180h255'],
  0x1D74A: [462,10,552,33,535,'303 423l5 39c127 0 227 -51 227 -174c0 -171 -151 -298 -291 -298c-93 0 -168 33 -168 109c0 11 4 37 12 71l29 125c5 22 12 49 12 66c0 16 -3 27 -17 27c-20 0 -41 -22 -59 -45l-20 12c32 52 90 103 160 103c40 0 59 -22 59 -48c0 -13 -5 -45 -10 -67l-40 -172 c-5 -22 -9 -44 -9 -64c0 -44 16 -77 67 -77c93 0 176 135 176 260c0 105 -65 133 -133 133'],
  0x1D74B: [462,205,706,55,667,'259 30l27 122c29 133 60 192 144 260c17 14 70 42 99 42c75 0 138 -62 138 -163c0 -144 -110 -290 -302 -301l-44 -195h-117l45 195c-126 10 -194 87 -194 188c0 162 138 284 297 284h41l-10 -39c-112 0 -212 -133 -212 -253c0 -70 34 -131 88 -140zM424 241l-49 -211 c78 7 176 122 176 267c0 88 -16 107 -39 107c-50 0 -76 -112 -88 -163'],
  0x1D74C: [462,204,621,33,676,'676 449l-293 -360l13 -121c8 -72 24 -102 44 -102c24 0 52 19 67 79h23c-21 -93 -52 -149 -117 -149c-64 0 -71 80 -74 161l-3 89l-182 -230h-121l302 363l-6 83c-7 99 -27 130 -60 130c-21 0 -54 -25 -67 -76h-23c8 62 36 146 121 146c54 0 73 -53 77 -157l3 -86 l177 230h119'],
  0x1D74D: [462,205,701,33,756,'756 462l-5 -39c-78 -7 -106 -71 -123 -142c-33 -141 -87 -291 -279 -291l-44 -195h-116l44 195c-103 8 -168 63 -168 169c0 61 42 125 40 193c-1 40 -25 64 -72 71l7 39h49c92 0 124 -54 124 -115c0 -68 -32 -132 -32 -198s24 -112 61 -119l98 419h116l-98 -419 c78 0 132 151 156 253c22 92 58 179 193 179h49'],
  0x1D74E: [462,10,687,22,665,'441 462h39c116 0 185 -76 185 -177c0 -155 -123 -295 -244 -295c-57 0 -87 28 -104 65c-40 -47 -89 -65 -144 -65c-106 0 -151 84 -151 176c0 91 52 189 130 243c49 34 104 53 173 53h32l-10 -39c-42 0 -82 -22 -112 -47c-64 -54 -97 -155 -97 -249c0 -48 24 -97 60 -97 c31 0 71 30 89 90c-6 28 -10 55 -10 84c0 70 31 168 107 168c42 0 52 -36 52 -71c0 -62 -42 -131 -74 -179c-1 -5 -2 -13 -2 -18c0 -49 34 -74 66 -74c71 0 123 162 123 247c0 91 -35 146 -116 146'],
  0x1D74F: [686,10,559,44,559,'234 627l2 23c30 25 79 36 119 36c130 0 204 -80 204 -256c0 -171 -103 -440 -328 -440c-120 0 -187 66 -187 176c0 159 139 293 298 293c50 0 115 -24 133 -70h4v8c1 9 2 18 2 27c0 114 -20 221 -154 221c-26 0 -58 -8 -93 -18zM423 293c0 91 -43 126 -89 126 c-88 0 -174 -152 -174 -265c0 -97 28 -124 88 -124c92 0 175 135 175 263'],
  0x1D750: [461,10,481,44,481,'481 461l-26 -140h-23c0 54 -6 103 -89 103c-73 0 -141 -88 -163 -161h188l-10 -44h-188c-7 -21 -10 -43 -10 -66c0 -79 40 -118 101 -118c67 0 113 36 152 79l18 -6c-30 -40 -89 -118 -223 -118c-116 0 -164 76 -164 158c0 150 128 313 283 313c70 0 76 -19 98 -19 c10 0 28 5 33 19h23'],
  0x1D751: [698,13,607,33,584,'584 241l-5 -31c-22 1 -45 2 -67 6c-41 -105 -104 -229 -234 -229c-87 0 -160 28 -160 128c0 35 11 72 16 107v4c0 10 -5 23 -17 23c-22 0 -51 -33 -64 -49l-20 18c31 47 93 99 152 99c47 0 66 -41 66 -82c0 -11 -2 -21 -4 -31c-9 -40 -19 -79 -19 -120 c0 -33 9 -68 50 -68c67 0 114 175 128 228c-104 50 -204 126 -204 252c0 115 76 202 194 202c32 0 66 -10 94 -26c67 -39 80 -119 80 -190c0 -78 -19 -155 -44 -228c19 -6 38 -11 58 -13zM454 541c0 40 -4 119 -60 119c-64 0 -80 -98 -80 -146c0 -83 46 -160 105 -215 c19 79 35 160 35 242'],
  0x1D752: [462,15,607,-12,630,'630 449l-154 -146c-12 -24 -23 -55 -33 -92c-9 -33 -13 -59 -13 -78c0 -24 12 -36 36 -36c20 0 36 -6 46 -18c8 -9 11 -20 11 -33c0 -17 -6 -32 -17 -43c-12 -12 -29 -18 -52 -18c-29 0 -51 12 -65 36c-11 18 -16 41 -16 69c0 55 13 105 39 153l-260 -243h-164l157 147 c12 24 23 55 33 91c9 33 13 58 13 76c0 24 -12 36 -36 36c-20 0 -35 6 -45 18c-8 9 -12 20 -12 33c0 17 6 31 17 42c12 12 30 19 52 19c29 0 51 -12 65 -36c11 -18 16 -42 16 -69c0 -52 -13 -102 -38 -150l256 242h164'],
  0x1D753: [685,205,683,44,655,'512 685l-51 -223c106 0 194 -55 194 -169c0 -44 -10 -87 -29 -127c-51 -109 -154 -169 -273 -176l-44 -195h-117l45 195c-110 8 -193 73 -193 188c0 44 12 87 32 126c54 102 155 158 269 158l50 223h117zM453 423l-90 -393c84 17 154 123 171 202c4 17 5 35 5 53 c0 55 -24 128 -86 138zM247 30l90 393c-103 -16 -177 -151 -177 -248c0 -59 21 -131 87 -145'],
  0x1D754: [462,205,585,44,563,'252 -205h-19c3 7 3 13 3 15c0 59 -192 76 -192 220c0 195 125 432 326 432c115 0 193 -55 193 -168c0 -159 -133 -304 -297 -304c-57 0 -101 18 -131 61l-5 -1c1 -109 150 -112 150 -184c0 -23 -3 -48 -28 -71zM448 297c0 91 -43 125 -89 125c-88 0 -174 -157 -174 -270 c0 -97 28 -122 88 -122c92 0 175 139 175 267'],
  0x1D755: [449,10,868,33,879,'879 449l-21 -91h-73c10 -22 15 -47 15 -75c0 -155 -123 -293 -244 -293c-57 0 -87 28 -104 65c-40 -47 -89 -65 -144 -65c-106 0 -151 84 -151 176c0 70 29 138 78 192h-36c-59 0 -108 -28 -143 -91h-23c23 81 84 182 248 182h598zM668 358h-312 c-54 -56 -83 -145 -83 -231c0 -48 24 -97 60 -97c31 0 69 27 87 87c-3 17 -6 39 -6 57c0 36 16 160 95 160c36 0 44 -33 44 -68c0 -59 -24 -96 -56 -144c-1 -5 -2 -13 -2 -18c0 -49 34 -74 66 -74c71 0 123 160 123 245c0 34 -5 61 -16 83']
};

MathJax.Ajax.loadComplete(MathJax.OutputJax.SVG.fontDir+"/Normal/BoldItalic/Main.js");
